# gradientai.openapi.client
Interface for interacting with Gradient AI.

The `gradientai.openapi.client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://docs.gradient.ai/discuss](https://docs.gradient.ai/discuss)

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* pydantic
* aenum

## Getting Started

In your own code, to use this library to connect and interact with gradientai.openapi.client,
you can run the following:

```python

import time
import gradientai.openapi.client
from gradientai.openapi.client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.gradient.ai/api
# See configuration.py for a list of all supported configuration parameters.
configuration = gradientai.openapi.client.Configuration(
    host = "https://api.gradient.ai/api"
)

# The client must configure the authentication parameter for being able to make the call. Gradient uses
# access tokens, which can be generated by going to https://auth.gradient.ai/select-workspace and selecting
# "Access tokens" under the profile drop-down.

# Configure Bearer authorization: AccessToken
configuration = gradientai.openapi.client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with gradientai.openapi.client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = gradientai.openapi.client.BlocksApi(api_client)
    x_gradient_workspace_id = 'x_gradient_workspace_id_example' # str | 
    analyze_sentiment_body_params = gradientai.openapi.client.AnalyzeSentimentBodyParams() # AnalyzeSentimentBodyParams | 

    try:
        # Sentiment analysis
        api_response = api_instance.analyze_sentiment(x_gradient_workspace_id, analyze_sentiment_body_params)
        print("The response of BlocksApi->analyze_sentiment:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BlocksApi->analyze_sentiment: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BlocksApi* | [**analyze_sentiment**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#analyze_sentiment) | **POST** /blocks/analyze-sentiment | Sentiment analysis
*BlocksApi* | [**create_audio_transcription**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#create_audio_transcription) | **POST** /blocks/transcription | Create audio transcription
*BlocksApi* | [**extract_entity**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#extract_entity) | **POST** /blocks/extract | Entity extraction
*BlocksApi* | [**extract_pdf**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#extract_pdf) | **POST** /blocks/extract-pdf | PDF extraction
*BlocksApi* | [**generate_answer**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#generate_answer) | **POST** /blocks/answer | Document question &amp; answer
*BlocksApi* | [**get_audio_transcription**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#get_audio_transcription) | **GET** /blocks/transcription | Get audio transcription
*BlocksApi* | [**personalize_document**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#personalize_document) | **POST** /blocks/personalize | Document personalization
*BlocksApi* | [**summarize_document**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BlocksApi.md#summarize_document) | **POST** /blocks/summarize | Document summary
*EmbeddingsApi* | [**generate_embedding**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/EmbeddingsApi.md#generate_embedding) | **POST** /embeddings/{slug} | Generate embeddings
*EmbeddingsApi* | [**list_embeddings**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/EmbeddingsApi.md#list_embeddings) | **GET** /embeddings | List available embeddings models
*FilesApi* | [**upload_file**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FilesApi.md#upload_file) | **POST** /files | File upload
*ModelsApi* | [**complete_model**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelsApi.md#complete_model) | **POST** /models/{id}/complete | Complete model
*ModelsApi* | [**create_model**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelsApi.md#create_model) | **POST** /models | Create model
*ModelsApi* | [**delete_model**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelsApi.md#delete_model) | **DELETE** /models/{id} | Delete model
*ModelsApi* | [**fine_tune_model**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelsApi.md#fine_tune_model) | **POST** /models/{id}/fine-tune | Fine-tune model
*ModelsApi* | [**get_model**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelsApi.md#get_model) | **GET** /models/{id} | Describe model
*ModelsApi* | [**list_models**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelsApi.md#list_models) | **GET** /models | List available models
*RAGApi* | [**add_files_to_rag_collection**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/RAGApi.md#add_files_to_rag_collection) | **POST** /rag-collections/{id}/files | Add files to RAG collection
*RAGApi* | [**create_rag_collection**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/RAGApi.md#create_rag_collection) | **POST** /rag-collections | Create RAG collection
*RAGApi* | [**delete_rag_collection**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/RAGApi.md#delete_rag_collection) | **DELETE** /rag-collections/{id} | Delete RAG collection
*RAGApi* | [**get_rag_collection**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/RAGApi.md#get_rag_collection) | **GET** /rag-collections/{id} | Get RAG collection
*RAGApi* | [**list_rag_collections**](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/RAGApi.md#list_rag_collections) | **GET** /rag-collections | List RAG collections


## Documentation For Models

 - [AddFilesToRagCollectionBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/AddFilesToRagCollectionBodyParams.md)
 - [AddFilesToRagCollectionError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/AddFilesToRagCollectionError.md)
 - [AnalyzeSentimentBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/AnalyzeSentimentBodyParams.md)
 - [AnalyzeSentimentBodyParamsExamplesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/AnalyzeSentimentBodyParamsExamplesInner.md)
 - [AnalyzeSentimentError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/AnalyzeSentimentError.md)
 - [AnalyzeSentimentSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/AnalyzeSentimentSuccess.md)
 - [BaseModel](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/BaseModel.md)
 - [CompleteModelBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelBodyParams.md)
 - [CompleteModelBodyParamsGuidance](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelBodyParamsGuidance.md)
 - [CompleteModelBodyParamsRag](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelBodyParamsRag.md)
 - [CompleteModelError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelError.md)
 - [CompleteModelErrorOneOf](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf.md)
 - [CompleteModelErrorOneOf1](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf1.md)
 - [CompleteModelErrorOneOf10](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf10.md)
 - [CompleteModelErrorOneOf1Payload](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf1Payload.md)
 - [CompleteModelErrorOneOf2](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf2.md)
 - [CompleteModelErrorOneOf3](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf3.md)
 - [CompleteModelErrorOneOf4](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf4.md)
 - [CompleteModelErrorOneOf5](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf5.md)
 - [CompleteModelErrorOneOf6](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf6.md)
 - [CompleteModelErrorOneOf7](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf7.md)
 - [CompleteModelErrorOneOf8](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf8.md)
 - [CompleteModelErrorOneOf9](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOf9.md)
 - [CompleteModelErrorOneOfPayload](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOfPayload.md)
 - [CompleteModelErrorOneOfPayloadFlaggedContentInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelErrorOneOfPayloadFlaggedContentInner.md)
 - [CompleteModelSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CompleteModelSuccess.md)
 - [CreateAudioTranscriptionBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateAudioTranscriptionBodyParams.md)
 - [CreateAudioTranscriptionError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateAudioTranscriptionError.md)
 - [CreateAudioTranscriptionSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateAudioTranscriptionSuccess.md)
 - [CreateModelBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelBodyParams.md)
 - [CreateModelBodyParamsInitialHyperparameters](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelBodyParamsInitialHyperparameters.md)
 - [CreateModelBodyParamsInitialHyperparametersLoraHyperparameters](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelBodyParamsInitialHyperparametersLoraHyperparameters.md)
 - [CreateModelBodyParamsInitialHyperparametersTrainingArguments](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelBodyParamsInitialHyperparametersTrainingArguments.md)
 - [CreateModelBodyParamsModel](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelBodyParamsModel.md)
 - [CreateModelError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelError.md)
 - [CreateModelSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateModelSuccess.md)
 - [CreateRagCollectionBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateRagCollectionBodyParams.md)
 - [CreateRagCollectionBodyParamsFilesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateRagCollectionBodyParamsFilesInner.md)
 - [CreateRagCollectionError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateRagCollectionError.md)
 - [CreateRagCollectionSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/CreateRagCollectionSuccess.md)
 - [DeleteModelError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/DeleteModelError.md)
 - [DeleteRagCollectionError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/DeleteRagCollectionError.md)
 - [ExtractEntityBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractEntityBodyParams.md)
 - [ExtractEntityBodyParamsSchemaValue](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractEntityBodyParamsSchemaValue.md)
 - [ExtractEntityError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractEntityError.md)
 - [ExtractEntitySuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractEntitySuccess.md)
 - [ExtractEntitySuccessEntityValue](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractEntitySuccessEntityValue.md)
 - [ExtractPdfError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfError.md)
 - [ExtractPdfSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccess.md)
 - [ExtractPdfSuccessPagesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccessPagesInner.md)
 - [ExtractPdfSuccessPagesInnerImagesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccessPagesInnerImagesInner.md)
 - [ExtractPdfSuccessPagesInnerTablesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccessPagesInnerTablesInner.md)
 - [ExtractPdfSuccessPagesInnerTablesInnerTableRowsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccessPagesInnerTablesInnerTableRowsInner.md)
 - [ExtractPdfSuccessPagesInnerTablesInnerTableRowsInnerCellsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccessPagesInnerTablesInnerTableRowsInnerCellsInner.md)
 - [ExtractPdfSuccessPagesInnerTextBlocksInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ExtractPdfSuccessPagesInnerTextBlocksInner.md)
 - [FineTuneModelBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelBodyParams.md)
 - [FineTuneModelBodyParamsSamplesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelBodyParamsSamplesInner.md)
 - [FineTuneModelBodyParamsSamplesInnerFineTuningParameters](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelBodyParamsSamplesInnerFineTuningParameters.md)
 - [FineTuneModelBodyParamsSamplesInnerInputs](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelBodyParamsSamplesInnerInputs.md)
 - [FineTuneModelBodyParamsSamplesInnerInputsAnyOfInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelBodyParamsSamplesInnerInputsAnyOfInner.md)
 - [FineTuneModelError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelError.md)
 - [FineTuneModelErrorOneOf](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelErrorOneOf.md)
 - [FineTuneModelErrorOneOf1](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelErrorOneOf1.md)
 - [FineTuneModelSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/FineTuneModelSuccess.md)
 - [GenerateAnswerBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerBodyParams.md)
 - [GenerateAnswerBodyParamsSource](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerBodyParamsSource.md)
 - [GenerateAnswerBodyParamsSourceOneOf](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerBodyParamsSourceOneOf.md)
 - [GenerateAnswerBodyParamsSourceOneOf1](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerBodyParamsSourceOneOf1.md)
 - [GenerateAnswerError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerError.md)
 - [GenerateAnswerSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerSuccess.md)
 - [GenerateAnswerSuccessRagContext](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerSuccessRagContext.md)
 - [GenerateAnswerSuccessRagContextDocumentsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateAnswerSuccessRagContextDocumentsInner.md)
 - [GenerateEmbeddingBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateEmbeddingBodyParams.md)
 - [GenerateEmbeddingBodyParamsInputsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateEmbeddingBodyParamsInputsInner.md)
 - [GenerateEmbeddingError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateEmbeddingError.md)
 - [GenerateEmbeddingSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateEmbeddingSuccess.md)
 - [GenerateEmbeddingSuccessEmbeddingsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GenerateEmbeddingSuccessEmbeddingsInner.md)
 - [GetAudioTranscriptionError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetAudioTranscriptionError.md)
 - [GetAudioTranscriptionSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetAudioTranscriptionSuccess.md)
 - [GetAudioTranscriptionSuccessOneOf](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetAudioTranscriptionSuccessOneOf.md)
 - [GetAudioTranscriptionSuccessOneOf1](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetAudioTranscriptionSuccessOneOf1.md)
 - [GetAudioTranscriptionSuccessOneOf1Result](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetAudioTranscriptionSuccessOneOf1Result.md)
 - [GetModelError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetModelError.md)
 - [GetModelSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetModelSuccess.md)
 - [GetRagCollectionError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetRagCollectionError.md)
 - [GetRagCollectionSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetRagCollectionSuccess.md)
 - [GetRagCollectionSuccessFilesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/GetRagCollectionSuccessFilesInner.md)
 - [ListEmbeddingsError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListEmbeddingsError.md)
 - [ListEmbeddingsSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListEmbeddingsSuccess.md)
 - [ListEmbeddingsSuccessEmbeddingsModelsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListEmbeddingsSuccessEmbeddingsModelsInner.md)
 - [ListModelsError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListModelsError.md)
 - [ListModelsSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListModelsSuccess.md)
 - [ListModelsSuccessModelsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListModelsSuccessModelsInner.md)
 - [ListRagCollectionsError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListRagCollectionsError.md)
 - [ListRagCollectionsSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListRagCollectionsSuccess.md)
 - [ListRagCollectionsSuccessRagCollectionsInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ListRagCollectionsSuccessRagCollectionsInner.md)
 - [ModelAdapter](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/ModelAdapter.md)
 - [PersonalizeDocumentBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/PersonalizeDocumentBodyParams.md)
 - [PersonalizeDocumentError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/PersonalizeDocumentError.md)
 - [PersonalizeDocumentSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/PersonalizeDocumentSuccess.md)
 - [SummarizeDocumentBodyParams](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/SummarizeDocumentBodyParams.md)
 - [SummarizeDocumentBodyParamsExamplesInner](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/SummarizeDocumentBodyParamsExamplesInner.md)
 - [SummarizeDocumentError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/SummarizeDocumentError.md)
 - [SummarizeDocumentSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/SummarizeDocumentSuccess.md)
 - [UploadFileError](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/UploadFileError.md)
 - [UploadFileSuccess](https://github.com/Preemo-Inc/gradientai-python-sdk/blob/main/gradientai/openapi/client/docs/UploadFileSuccess.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="AccessToken"></a>
### AccessToken

- **Type**: Bearer authentication


## Author

support@gradient.ai


